﻿using System;
using System.Collections.Generic;
using System.Text;


/*
 * 
 * DISCLAIMER OF WARRANTY: THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 * WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS, MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE OR NON-INFRINGING.
 * THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH YOU. SHOULD ANY COVERED CODE PROVE DEFECTIVE IN ANY RESPECT,
 * YOU (NOT CORPORATE EASY GIS .NET) ASSUME THE COST OF ANY NECESSARY SERVICING, REPAIR OR CORRECTION.  
 * 
 * LIABILITY: IN NO EVENT SHALL CORPORATE EASY GIS .NET BE LIABLE FOR ANY DAMAGES WHATSOEVER (INCLUDING, WITHOUT LIMITATION, 
 * DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS INTERRUPTION, LOSS OF INFORMATION OR ANY OTHER PECUNIARY LOSS)
 * ARISING OUT OF THE USE OF INABILITY TO USE THIS SOFTWARE, EVEN IF CORPORATE EASY GIS .NET HAS BEEN ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGES.
 * 
 * Copyright: Easy GIS .NET 2013
 *
 */
namespace Example10
{
    /// <summary>
    /// stores a "xyz" record contained in a .xyz file
    /// </summary>
    public struct XYZRecord
    {
        double x;
        double y;
        double z;
      
        public XYZRecord(double x,
            double y,
            double height)
        {
            this.x = x;
            this.y = y;
            this.z = height;
           
        }

        public double X
        {
            get { return x; }
            set { x = value; }
        }

        public double Y
        {
            get { return y; }
            set { y = value; }
        }

        public double Z
        {
            get { return z; }
            set { z = value; }
        }
    }

    /// <summary>
    /// Class to hold a collection of XYZRecords
    /// </summary>
    public class XYZRecordList : List<XYZRecord>
    {

        /// <summary>
        /// Reads XYZRecords from a text stream read from a .xyz file
        /// </summary>
        /// <param name="reader"></param>
        /// <remarks>
        /// <para>
        /// The .XYZ is a simple text file. The file contains no header with the first record appearing in the first row. Each row is separated by a new line
        /// </para>
        /// <para>
        /// The format of each record is : <br/>
        /// Easting(X),Northing(y)
        /// </para>
        /// </remarks>
        public void ReadRecords(System.IO.TextReader reader)
        {
            string nextLine;
            while ((nextLine = reader.ReadLine()) != null)
            {
                string[] tokens = nextLine.Split(new char[] { ',' }, StringSplitOptions.RemoveEmptyEntries);
                
                if (tokens.Length >= 2)
                {
                    double x, y;
                    if (!double.TryParse(tokens[0].Trim(), System.Globalization.NumberStyles.Float, System.Globalization.CultureInfo.InvariantCulture, out x)) continue;
                    if (!double.TryParse(tokens[1].Trim(), System.Globalization.NumberStyles.Float, System.Globalization.CultureInfo.InvariantCulture, out y)) continue;
                    Add(new XYZRecord(x, y, 0));                    
                }

            }
        }

    }

}
